pub struct FileSystemPersistence { /* private fields */ }Expand description
Simple file-based persistence implementation.
This implementation stores the state in a single file on disk. It provides persistent storage that survives process restarts.
Implementations
Sourceimpl FileSystemPersistence
impl FileSystemPersistence
Sourcepub fn new_sync<P: AsRef<Path>>(data_dir: P) -> Result<Self>
pub fn new_sync<P: AsRef<Path>>(data_dir: P) -> Result<Self>
Create a new file-based persistence instance (synchronous).
This is a convenience method that blocks on the async new method.
Arguments
data_dir- Directory path where the state file will be stored
Returns
- A new
FileSystemPersistenceinstance
Errors
- Returns error if the data directory cannot be created